@@ -7,79 +7,79 @@
 #' procedure in general is given by Murray and Wintle (2000). For the
 #' calculation of the Lx/Tx value the function [calc_TLLxTxRatio] is
 #' used.
-#' 
+#'
 #' **Provided rejection criteria**
-#' 
+#'
 #' `[recyling.ratio]`: calculated for every repeated regeneration dose point.
-#' 
+#'
 #' `[recuperation.rate]`: recuperation rate calculated by
 #' comparing the Lx/Tx values of the zero regeneration point with the Ln/Tn
 #' value (the Lx/Tx ratio of the natural signal).  For methodological
 #' background see Aitken and Smith (1988)
 #'
-#' @param object [RLum.Analysis-class](**required**): 
+#' @param object [RLum.Analysis-class] or a [list] of such objects (**required**) :
 #' input object containing data for analysis
 #'
 #' @param object.background currently not used
 #'
-#' @param signal.integral.min [integer] (**required**): 
-#' requires the channel number for the lower signal integral bound 
+#' @param signal.integral.min [integer] (**required**):
+#' requires the channel number for the lower signal integral bound
 #' (e.g. `signal.integral.min = 100`)
 #'
-#' @param signal.integral.max [integer] (**required**): 
-#' requires the channel number for the upper signal integral bound 
+#' @param signal.integral.max [integer] (**required**):
+#' requires the channel number for the upper signal integral bound
 #' (e.g. `signal.integral.max = 200`)
 #'
-#' @param integral_input [character] (*with default*): 
-#' defines the input for the the arguments `signal.integral.min` and 
-#' `signal.integral.max`. These limits can be either provided `'channel'` 
-#' number (the default) or `'temperature'`. If `'temperature'` is chosen the 
+#' @param integral_input [character] (*with default*):
+#' defines the input for the the arguments `signal.integral.min` and
+#' `signal.integral.max`. These limits can be either provided `'channel'`
+#' number (the default) or `'temperature'`. If `'temperature'` is chosen the
 #' best matching channel is selected.
 #'
 #' @param sequence.structure [vector] [character] (*with default*):
-#' specifies the general sequence structure. Three steps are allowed 
+#' specifies the general sequence structure. Three steps are allowed
 #' (`"PREHEAT"`, `"SIGNAL"`, `"BACKGROUND"`), in addition a
 #' parameter `"EXCLUDE"`. This allows excluding TL curves which are not
 #' relevant for the protocol analysis.  (**Note:** None TL are removed by default)
 #'
-#' @param rejection.criteria [list] (*with default*): 
+#' @param rejection.criteria [list] (*with default*):
 #' list containing rejection criteria in percentage for the calculation.
 #'
-#' @param dose.points [numeric] (*optional*): 
+#' @param dose.points [numeric] (*optional*):
 #' option set dose points manually
 #'
-#' @param log [character] (*with default*): 
-#' a character string which contains "x" if the x axis is to be logarithmic, 
+#' @param log [character] (*with default*):
+#' a character string which contains "x" if the x axis is to be logarithmic,
 #' "y" if the y axis is to be logarithmic and "xy" or "yx" if both axes are to be logarithmic. See
 #' [plot.default]).
 #'
 #' @param ... further arguments that will be passed to the function [plot_GrowthCurve]
 #'
-#' @return 
+#' @return
 #' A plot (*optional*) and an [RLum.Results-class] object is
 #' returned containing the following elements:
-#' 
-#' \item{De.values}{[data.frame] containing De-values and further parameters} 
+#'
+#' \item{De.values}{[data.frame] containing De-values and further parameters}
 #' \item{LnLxTnTx.values}{[data.frame] of all calculated Lx/Tx values including signal, background counts and the dose points.}
 #' \item{rejection.criteria}{[data.frame] with values that might by used as rejection criteria. NA is produced if no R0 dose point exists.}
-#' 
+#'
 #' **note:** the output should be accessed using the function [get_RLum]
 #'
-#' @note 
+#' @note
 #' **THIS IS A BETA VERSION**
-#' 
+#'
 #' None TL curves will be removed
 #' from the input object without further warning.
 #'
-#' @section Function version: 0.2.0
+#' @section Function version: 0.3.0
 #'
-#' @author 
-#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' @author
+#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CRNS-Universite Bordeaux Montaigne (France)
 #'
 #' @seealso [calc_TLLxTxRatio], [plot_GrowthCurve], [RLum.Analysis-class],
 #' [RLum.Results-class], [get_RLum]
 #'
-#' @references 
+#' @references
 #' Aitken, M.J. and Smith, B.W., 1988. Optical dating: recuperation
 #' after bleaching.  Quaternary Science Reviews 7, 387-393.
 #'
@@ -98,12 +98,12 @@
 #' object <- Risoe.BINfileData2RLum.Analysis(TL.SAR.Data, pos=3)
 #'
 #' ##perform analysis
-#' analyse_SAR.TL(object,
-#'                signal.integral.min = 210,
-#'                signal.integral.max = 220,
-#'                log = "y",
-#'                fit.method = "EXP OR LIN",
-#'                sequence.structure = c("SIGNAL", "BACKGROUND"))
+#' analyse_SAR.TL(
+#'  object = object,
+#'  signal.integral.min = 210,
+#'  signal.integral.max = 220,
+#'  fit.method = "EXP OR LIN",
+#'  sequence.structure = c("SIGNAL", "BACKGROUND"))
 #'
 #' @md
 #' @export
@@ -120,6 +120,37 @@ analyse_SAR.TL <- function(
   ...
 ){
 
+
+  # Self-call -----------------------------------------------------------------------------------
+  if(class(object) == "list"){
+   if(!all(sapply(object, class) == "RLum.Analysis"))
+     stop("[analyse_SAR.TL()] All elements in the input list need to be of class 'RLum.Analysis'!",
+          call. = FALSE)
+
+    ##run sequence
+    results <- lapply(object, function(o){
+      analyse_SAR.TL(
+        object = o,
+        object.background = object.background,
+        signal.integral.min = signal.integral.min,
+        signal.integral.max = signal.integral.max,
+        integral_input = integral_input,
+        sequence.structure =  sequence.structure,
+        rejection.criteria = rejection.criteria,
+        dose.points = dose.points,
+        log = log,
+        ...
+      )
+    })
+
+    ##combine results
+    results <- merge_RLum(results)
+
+    ##return
+    return(results)
+
+  }
+
   # CONFIG  -----------------------------------------------------------------
 
   ##set allowed curve types
@@ -132,20 +163,20 @@ analyse_SAR.TL <- function(
 
   ##MISSING INPUT
   if(missing("object")==TRUE){
-    stop("[analyse_SAR.TL] No value set for 'object'!")
+    stop("[analyse_SAR.TL()] No value set for 'object'!", call. = FALSE)
   }
 
   if(missing("signal.integral.min") == TRUE){
-    stop("[analyse_SAR.TL] No value set for 'signal.integral.min'!")
+    stop("[analyse_SAR.TL()] No value set for 'signal.integral.min'!", call. = FALSE)
   }
 
   if(missing("signal.integral.max") == TRUE){
-    stop("[analyse_SAR.TL] No value set for 'signal.integral.max'!")
+    stop("[analyse_SAR.TL()] No value set for 'signal.integral.max'!", call. = FALSE)
   }
 
   ##INPUT OBJECTS
   if(is(object, "RLum.Analysis") == FALSE){
-    stop("[analyse_SAR.TL] Input object is not of type 'RLum.Analyis'!")
+    stop("[analyse_SAR.TL()] Input object is not of type 'RLum.Analyis'!", call. = FALSE)
   }
 
 
@@ -169,7 +200,6 @@ analyse_SAR.TL <- function(
   temp.sequence.structure <- temp.sequence.structure[which(
     temp.sequence.structure[,"protocol.step"]!="EXCLUDE"),]
 
-
   ##check integrity; signal and bg range should be equal
   if(length(
     unique(
@@ -214,7 +244,6 @@ analyse_SAR.TL <- function(
 
   ##calculate LxTx values using external function
   for(i in seq(1,length(TL.signal.ID),by=2)){
-
     temp.LnLxTnTx <- get_RLum(
       calc_TLLxTxRatio(
         Lx.data.signal = get_RLum(object, record.id = TL.signal.ID[i]),
@@ -257,7 +286,7 @@ analyse_SAR.TL <- function(
     }
   }
 
-  ##set dose.points manual if argument was set
+  ##set dose.points manually if argument was set
   if(!missing(dose.points)){
     temp.Dose <- dose.points
     LnLxTnTx$Dose <- dose.points
@@ -265,14 +294,13 @@ analyse_SAR.TL <- function(
   }
 
   # Set regeneration points -------------------------------------------------
-
   #generate unique dose id - this are also the # for the generated points
-  temp.DoseID <- c(0:(length(temp.Dose)-1))
-  temp.DoseName <- paste("R",temp.DoseID,sep="")
-  temp.DoseName <- cbind(Name=temp.DoseName,Dose=temp.Dose)
+  temp.DoseID <- c(0:(length(LnLxTnTx[["Dose"]]) - 1))
+  temp.DoseName <- paste0("R", temp.DoseID)
+  temp.DoseName <- cbind(Name = temp.DoseName, Dose = LnLxTnTx[["Dose"]])
 
   ##set natural
-  temp.DoseName[temp.DoseName[,"Name"]=="R0","Name"]<-"Natural"
+  temp.DoseName[temp.DoseName[, "Name"] == "R0", "Name"] <- "Natural"
 
   ##set R0
   temp.DoseName[temp.DoseName[,"Name"]!="Natural" & temp.DoseName[,"Dose"]==0,"Name"]<-"R0"
@@ -287,14 +315,13 @@ analyse_SAR.TL <- function(
   temp.DoseName[temp.DoseName[,"Dose"]==0,"Repeated"]<-FALSE
 
   ##combine in the data frame
-  temp.LnLxTnTx<-data.frame(Name=temp.DoseName[,"Name"],
-                            Repeated=as.logical(temp.DoseName[,"Repeated"]))
+  temp.LnLxTnTx <- data.frame(Name = temp.DoseName[, "Name"],
+                              Repeated = as.logical(temp.DoseName[, "Repeated"]))
 
 
   LnLxTnTx<-cbind(temp.LnLxTnTx,LnLxTnTx)
   LnLxTnTx[,"Name"]<-as.character(LnLxTnTx[,"Name"])
 
-
   # Calculate Recycling Ratio -----------------------------------------------
 
   ##Calculate Recycling Ratio
@@ -373,18 +400,19 @@ analyse_SAR.TL <- function(
   par.default <- par(no.readonly = TRUE)
   on.exit(par(par.default))
 
-  ##colours and double for plotting
+  ##grep colours
   col <- get("col", pos = .LuminescenceEnv)
 
-  col.doubled <- rep(col, each=2)
+  ##set layout matrix
+  layout(matrix(c(
+    1, 1, 2, 2,
+    1, 1, 2, 2,
+    3, 3, 4, 4,
+    3, 3, 4, 4,
+    5, 5, 5, 5
+  ), 5, 4, byrow = TRUE))
 
-  layout(matrix(c(1,1,2,2,
-                  1,1,2,2,
-                  3,3,4,4,
-                  3,3,4,4,
-                  5,5,5,5),5,4,byrow=TRUE))
-
-  par(oma=c(0,0,0,0), mar=c(4,4,3,3))
+  par(oma = c(0, 0, 0, 0), mar = c(4, 4, 3, 3))
 
   ## 1 -> TL Lx
   ## 2 -> TL Tx
@@ -404,62 +432,84 @@ analyse_SAR.TL <- function(
   }
 
 
-  # # Plotting TL Lx Curves ----------------------------------------------------
+  # # Plotting TL LnLx Curves ----------------------------------------------------
+  ##matrix with LnLx curves
+  LnLx_matrix <- vapply(seq(1, length(TL.signal.ID), by = 2), function(x){
+    if(length(TL.background.ID) != 0){
+      object@records[[TL.signal.ID[x]]]@data[,2] -
+        object@records[[TL.background.ID[x]]]@data[,2]
+    }else{
+      object@records[[TL.signal.ID[x]]]@data[,2]
+    }
+  }, numeric(nrow(object@records[[TL.signal.ID[1]]]@data)))
+
+  ##add time axis
+  LnLx_matrix <- cbind(object@records[[TL.signal.ID[1]]]@data[,1], LnLx_matrix)
+
+  ##matrix with TnTx curves
+  TnTx_matrix <- vapply(seq(2, length(TL.signal.ID), by = 2), function(x){
+    if(length(TL.background.ID) != 0){
+      object@records[[TL.signal.ID[x]]]@data[,2] -
+        object@records[[TL.background.ID[x]]]@data[,2]
+    }else{
+      object@records[[TL.signal.ID[x]]]@data[,2]
+    }
+  }, numeric(nrow(object@records[[TL.signal.ID[1]]]@data)))
+
+  ##add time axis
+  TnTx_matrix <- cbind(object@records[[TL.signal.ID[1]]]@data[,1], TnTx_matrix)
+
+  ##catch log-scale problem
+  if(log != ""){
+    if(min(LnLx_matrix) <= 0 || min(TnTx_matrix) <= 0){
+      warning("[analyse_SAR.TL()] log-scale needs positive values; log-scale disabled!", call. = FALSE)
+    log <- ""
+    }
+
+  }
 
   #open plot area LnLx
   plot(NA,NA,
-       xlab="Temp. [\u00B0C]",
-       ylab=paste("TL [a.u.]",sep=""),
-       xlim=c(0.1,
-              max(temp.sequence.structure[temp.sequence.structure[,"protocol.step"]=="SIGNAL","x.max"])),
-       ylim=c(
-         min(temp.sequence.structure[temp.sequence.structure[,"protocol.step"]=="SIGNAL","y.min"]),
-         max(temp.sequence.structure[temp.sequence.structure[,"protocol.step"]=="SIGNAL","y.max"])),
-
-       main=expression(paste(L[n],",",L[x]," curves",sep="")),
-       log=log)
-
+       xlab = "Temp. [\u00B0C]",
+       ylab = paste0("TL [a.u.]"),
+       xlim = range(LnLx_matrix[, 1]),
+       ylim = range(LnLx_matrix[, -1]),
+       main = expression(paste(L[n], ",", L[x], " curves", sep = "")),
+       log = log
+  )
 
   ##plot curves
-  sapply(seq(1,length(TL.signal.ID),by=2), function(x){
-    lines(object@records[[TL.signal.ID[x]]]@data,col=col.doubled[x])
-
-  })
+  for (i in 2:ncol(LnLx_matrix)) {
+    lines(x = LnLx_matrix[, 1], y = LnLx_matrix[, i],
+          col = col[i - 1])
+  }
 
   ##mark integration limits
-  abline(v=min(signal.integral.temperature), lty=2, col="gray")
-  abline(v=max(signal.integral.temperature), lty=2, col="gray")
-
-
-  # Plotting TnTx Curves ----------------------------------------------------
+  abline(v = range(signal.integral.temperature), lty = 2, col = "gray")
 
   #open plot area TnTx
   plot(NA,NA,
-       xlab="Temp. [\u00B0C]",
-       ylab=paste("TL [a.u.]",sep=""),
-       xlim=c(0.1,
-              max(temp.sequence.structure[temp.sequence.structure[,"protocol.step"]=="SIGNAL","x.max"])),
-       ylim=c(
-         min(temp.sequence.structure[temp.sequence.structure[,"protocol.step"]=="SIGNAL","y.min"]),
-         max(temp.sequence.structure[temp.sequence.structure[,"protocol.step"]=="SIGNAL","y.max"])),
-
-       main=expression(paste(T[n],",",T[x]," curves",sep="")),
-       log=log)
-
+    xlab = "Temp. [\u00B0C]",
+    ylab = paste0("TL [a.u.]"),
+    xlim = range(TnTx_matrix[, 1]),
+    ylim = range(TnTx_matrix[, -1]),
+    main = expression(paste(T[n], ",", T[x], " curves", sep = "")),
+    log = log
+  )
 
   ##plot curves
-  sapply(seq(2,length(TL.signal.ID),by=2), function(x){
-    lines(object@records[[TL.signal.ID[x]]]@data,col=col.doubled[x])
-
-  })
+  for (i in 2:ncol(TnTx_matrix)) {
+    lines(x = TnTx_matrix[, 1], y = TnTx_matrix[, i],
+          col = col[i - 1])
+  }
 
   ##mark integration limits
-  abline(v=min(signal.integral.temperature), lty=2, col="gray")
-  abline(v=max(signal.integral.temperature), lty=2, col="gray")
+  abline(v = range(signal.integral.temperature), lty = 2, col = "gray")
 
+  ##clean
+  rm(LnLx_matrix, TnTx_matrix)
 
   # Plotting Plateau Test LnLx -------------------------------------------------
-
   if(length(TL.background.ID) != 0){
     NTL.net.LnLx <-
       data.frame(object@records[[TL.signal.ID[1]]]@data[, 1],
@@ -514,23 +564,26 @@ analyse_SAR.TL <- function(
 
 
     # Plotting Plateau Test TnTx -------------------------------------------------
-
     ##get NTL signal
-    NTL.net.TnTx <-
-      data.frame(object@records[[TL.signal.ID[2]]]@data[, 1],
+    NTL.net.TnTx <- matrix(
+      data = c(object@records[[TL.signal.ID[2]]]@data[, 1],
                  object@records[[TL.signal.ID[2]]]@data[, 2] -
-                   object@records[[TL.background.ID[2]]]@data[, 2])
+                   object@records[[TL.background.ID[2]]]@data[, 2]),
+      ncol = 2)
 
     ##get signal from the first regeneration point
-    Reg1.net.TnTx <-
-      data.frame(object@records[[TL.signal.ID[4]]]@data[, 1],
+    Reg1.net.TnTx <- matrix(
+      data = c(object@records[[TL.signal.ID[4]]]@data[, 1],
                  object@records[[TL.signal.ID[4]]]@data[, 2] -
-                   object@records[[TL.background.ID[4]]]@data[, 2])
+                   object@records[[TL.background.ID[4]]]@data[, 2]),
+      ncol = 2)
 
 
     ##combine values
-    TL.Plateau.TnTx <-
-      data.frame(NTL.net.TnTx[, 1], Reg1.net.TnTx[, 2] / NTL.net.TnTx[, 2])
+    TL.Plateau.TnTx <- matrix(
+      data = c(NTL.net.TnTx[, 1],
+               Reg1.net.TnTx[, 2] / NTL.net.TnTx[, 2]),
+      ncol = 2)
 
     ##Plot Plateau Test
     plot(
@@ -552,7 +605,6 @@ analyse_SAR.TL <- function(
     lines(NTL.net.TnTx, col = col[1])
     lines(Reg1.net.TnTx, col = col[2])
 
-
     ##plot
     par(new = TRUE)
     plot(
@@ -569,12 +621,7 @@ analyse_SAR.TL <- function(
     )
     axis(4)
 
-
-
-
     # Plotting Legend ----------------------------------------
-
-
     plot(
       c(1:(length(TL.signal.ID) / 2)),
       rep(8, length(TL.signal.ID) / 2),
@@ -605,12 +652,20 @@ analyse_SAR.TL <- function(
   }
 
   # Plotting  GC  ----------------------------------------
-  temp.sample <- data.frame(Dose=LnLxTnTx$Dose,
-                            LxTx=LnLxTnTx$LxTx,
-                            LxTx.Error=LnLxTnTx$LxTx.Error,
-                            TnTx=LnLxTnTx$TnTx
+  #reset par
+  par(par.default)
+
+  ##create data.frame
+  temp.sample <- data.frame(
+    Dose = LnLxTnTx$Dose,
+    LxTx = LnLxTnTx$LxTx,
+    LxTx.Error = LnLxTnTx$LxTx.Error,
+    TnTx = LnLxTnTx$TnTx
   )
 
+  ##set NA values to 0
+  temp.sample[is.na(temp.sample$LxTx.Error),"LxTx.Error"] <- 0
+
   ##run curve fitting
   temp.GC <- try(plot_GrowthCurve(
     sample = temp.sample,
@@ -627,7 +682,6 @@ analyse_SAR.TL <- function(
   }
 
 
-
   ##add recjection status
   if(length(grep("FAILED",RejectionCriteria$status))>0){
     temp.GC <- data.frame(temp.GC, RC.Status="FAILED")
@@ -638,7 +692,6 @@ analyse_SAR.TL <- function(
   }
 
   # Return Values -----------------------------------------------------------
-
   newRLumResults.analyse_SAR.TL <- set_RLum(
     class = "RLum.Results",
     data = list(
@@ -652,3 +705,4 @@ analyse_SAR.TL <- function(
   return(newRLumResults.analyse_SAR.TL)
 
 }
+
