@@ -10,7 +10,7 @@
 ##for coercing.
 ##
 ##(3) Finally, what ever you want to implemnt, check whether a S4-method exists, it should
-##be just passed to this methods, not the opposite, otherwise this will yield in undesired behaviour.
+##be just passed to this methods, not the opposite, otherwise this will yield in undesired behaviour
 ##
 ##TODO: For this S3 generics so far no proper documentation exists ... we should consider
 ##to provide an overview within a separat document, as it becomes otherwise rather
@@ -247,6 +247,12 @@ subset.RLum.Analysis <- function(x, subset = NULL, ...) {
 #' @export
 bin.RLum.Data.Curve <- function(x, bin_size = 2, ...) bin_RLum.Data(x, bin_size = bin_size)
 
+#' @rdname methods_RLum
+#' @export
+bin.RLum.Data.Spectrum <- function(x, bin_size.row = 1, bin_size.col = 1, ...){
+  bin_RLum.Data(x, bin_size.row = bin_size.row, bin_size.col = bin_size.col)
+}
+
 ####################################################################################################
 # methods for generic: length()
 # ##################################################################################################
