@@ -174,7 +174,7 @@
 #' `..$call` : \tab `call` \tab The original function call\cr
 #' }
 #'
-#' @section Function version: 1.10.5
+#' @section Function version: 1.10.10
 #'
 #' @author
 #' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)\cr
@@ -198,7 +198,11 @@
 #' temp <- plot_GrowthCurve(LxTxData)
 #' get_RLum(temp)
 #'
-#' ##(1a) to access the fitting value try
+#' ##(1b) horizontal plot arrangement
+#' layout(mat = matrix(c(1,1,2,3), ncol = 2))
+#' plot_GrowthCurve(LxTxData, output.plotExtended.single = TRUE)
+#'
+#' ##(1c) to access the fitting value try
 #' get_RLum(temp, data.object = "Fit")
 #'
 #' ##(2) plot the growth curve only - uncomment to use
@@ -308,7 +312,7 @@ plot_GrowthCurve <- function(
 
   ##2. check if sample contains a least three rows
   if(length(sample[[1]])<3 & fit.method != "LIN"){
-    stop("\n [plot_GrowthCurve()] At least two regeneration points are needed!")
+    stop("\n [plot_GrowthCurve()] At least two regeneration points are needed!", call. = FALSE)
   }
 
   ##2.1 check column numbers; we assume that in this particular case no error value
@@ -330,7 +334,7 @@ plot_GrowthCurve <- function(
   }
 
   ##2.3 check whether the dose value is equal all the time
-  if(sum(abs(diff(sample[[1]]))) == 0){
+  if(sum(abs(diff(sample[[1]])), na.rm = TRUE) == 0){
     try(stop("[plot_GrowthCurve()] All points have the same dose. NULL returned!", call. = FALSE))
     return(NULL)
 
@@ -495,15 +499,14 @@ plot_GrowthCurve <- function(
     data <-
       data.frame(x = xy[[1]][!duplicated(xy[[1]])], y = xy[[2]][!duplicated(xy[[1]])])
     fit.weights <- fit.weights[!duplicated(xy[[1]])]
-    data.MC <- data.MC[!duplicated(xy[[1]]),]
+    data.MC <- data.MC[!duplicated(xy[[1]]),,drop = FALSE]
     y.Error <- y.Error[!duplicated(xy[[1]])]
-    xy <- xy[!duplicated(xy[[1]]),]
+    xy <- xy[!duplicated(xy[[1]]),,drop = FALSE]
 
   }else{
     data <- data.frame(xy)
   }
 
-
   ## for unknown reasons with only two points the nls() function is trapped in
   ## an endless mode, therefore the minimum length for data is 3
   ## (2016-05-17)
@@ -622,7 +625,7 @@ plot_GrowthCurve <- function(
                                 upper = max(sample[, 1]) * 1.5), silent = TRUE)
 
       if (!inherits(De.uniroot, "try-error")) {
-        De <- round(De.uniroot$root, digits = 2)
+        De <- De.uniroot$root
         if (verbose) {
           if (mode != "alternate") {
             writeLines(paste0("[plot_GrowthCurve()] Fit: ", fit.method,
@@ -672,7 +675,6 @@ plot_GrowthCurve <- function(
       pb<-txtProgressBar(min=0,max=NumberIterations.MC, char="=", style=3)
     }
 
-
     #start loop for Monte Carlo Error estimation
     fit.MC <- sapply(1:NumberIterations.MC, function(i){
 
@@ -716,7 +718,7 @@ plot_GrowthCurve <- function(
         silent = TRUE)
 
         if (!inherits(De.uniroot.MC, "try-error")) {
-          De.MC <- round(De.uniroot.MC$root, digits = 2)
+          De.MC <- De.uniroot.MC$root
 
         } else{
           De.MC <- NA
@@ -764,7 +766,7 @@ plot_GrowthCurve <- function(
   if (fit.method=="EXP" | fit.method=="EXP OR LIN" | fit.method=="LIN"){
 
     if((is.na(a) | is.na(b) | is.na(c)) && fit.method != "LIN"){
-      try(stop("[plot_GrowthCurve()] Fit could not applied for this data set. NULL returned!", call. = FALSE))
+      try(stop("[plot_GrowthCurve()] Fit could not be applied for this data set. NULL returned!", call. = FALSE))
       return(NULL)
 
     }
@@ -860,7 +862,7 @@ plot_GrowthCurve <- function(
 
         #calculate De
         if(mode == "interpolation"){
-          De <- suppressWarnings(round(-c-b*log(1-sample[1,2]/a), digits=2))
+          De <- suppressWarnings(-c-b*log(1-sample[1,2]/a))
 
         }else if (mode == "extrapolation"){
           De <- suppressWarnings(-c-b*log(1-0/a))
@@ -872,7 +874,7 @@ plot_GrowthCurve <- function(
 
 
         #print D01 value
-        D01<-round(b,digits=2)
+        D01 <- b
         if (verbose) {
           if (mode != "alternate") {
             writeLines(paste0(
@@ -884,7 +886,7 @@ plot_GrowthCurve <- function(
               " | De = ",
               round(abs(De), digits = 2),
               " | D01 = ",
-              D01
+              round(D01, 2)
             ))
           }
         }
@@ -942,7 +944,7 @@ plot_GrowthCurve <- function(
             #calculate x.natural for error calculation
             if(mode == "interpolation"){
               x.natural[i]<-suppressWarnings(
-                round(-var.c[i]-var.b[i]*log(1-data.MC.De[i]/var.a[i]), digits=2))
+                -var.c[i]-var.b[i]*log(1-data.MC.De[i]/var.a[i]))
 
             }else if(mode == "extrapolation"){
               x.natural[i]<-suppressWarnings(
@@ -983,7 +985,7 @@ plot_GrowthCurve <- function(
 
         #calculate De
         if(mode == "interpolation"){
-          De <- round((sample[1,2]/fit.lm$coefficients[1]), digits=2)
+          De <- sample[1,2]/fit.lm$coefficients[1]
 
         }else{
           De <- 0
@@ -995,7 +997,7 @@ plot_GrowthCurve <- function(
 
         #calculate De
         if(mode == "interpolation"){
-          De <- round((sample[1,2]-fit.lm$coefficients[1])/fit.lm$coefficients[2], digits=2)
+          De <- (sample[1,2]-fit.lm$coefficients[1])/fit.lm$coefficients[2]
 
         }else if(mode == "extrapolation"){
           De <- (0-fit.lm$coefficients[1])/fit.lm$coefficients[2]
@@ -1027,8 +1029,7 @@ plot_GrowthCurve <- function(
       #start loop for Monte Carlo Error estimation
       #LIN MC ---------
       for (i in 1:NumberIterations.MC) {
-
-        data <- data.frame(x=xy$x, y=data.MC[,i])
+        data <- data.frame(x = xy$x, y = data.MC[, i])
 
         if(fit.force_through_origin){
 
@@ -1037,7 +1038,7 @@ plot_GrowthCurve <- function(
 
           #calculate x.natural
           if(mode == "interpolation"){
-            x.natural[i]<-round((data.MC.De[i]/fit.lmMC$coefficients[1]), digits=2)
+            x.natural[i] <- data.MC.De[i]/fit.lmMC$coefficients[1]
 
           }else if (mode == "extrapolation"){
             x.natural[i] <- 0
@@ -1052,11 +1053,11 @@ plot_GrowthCurve <- function(
 
           #calculate x.natural
           if(mode == "interpolation"){
-            x.natural[i]<-round((data.MC.De[i]-fit.lmMC$coefficients[1])/
-                                  fit.lmMC$coefficients[2], digits=2)
+            x.natural[i] <- (data.MC.De[i]-fit.lmMC$coefficients[1])/
+                                  fit.lmMC$coefficients[2]
 
           }else if (mode == "extrapolation"){
-            x.natural[i]<-abs((0-fit.lmMC$coefficients[1])/
+            x.natural[i] <- abs((0-fit.lmMC$coefficients[1])/
                                   fit.lmMC$coefficients[2])
 
           }
@@ -1198,7 +1199,7 @@ plot_GrowthCurve <- function(
 
 
         if (class(temp.De) != "try-error") {
-          De <- round(temp.De$root, digits = 2)
+          De <- temp.De$root
         } else{
           De <- NA
         }
@@ -1478,7 +1479,7 @@ plot_GrowthCurve <- function(
 
 
         if (class(temp.De) != "try-error") {
-          De <- round(temp.De$root, digits = 2)
+          De <- temp.De$root
         } else{
           De <- NA
         }
@@ -1638,7 +1639,7 @@ plot_GrowthCurve <- function(
 
       #calculate De
       if(mode == "interpolation"){
-        De <- suppressWarnings(round(-(b * (( (a - sample[1,2])/a)^c - 1) * ( ((a - sample[1,2])/a)^-c  )) / c, digits=2))
+        De <- suppressWarnings(-(b * (( (a - sample[1,2])/a)^c - 1) * ( ((a - sample[1,2])/a)^-c  )) / c)
 
       }else if (mode == "extrapolation"){
         De <- suppressWarnings(-(b * (( (a - 0)/a)^c - 1) * ( ((a - 0)/a)^-c  )) / c)
@@ -1649,7 +1650,7 @@ plot_GrowthCurve <- function(
       }
 
       #print D01 value
-      D01<-round(b, digits=2)
+      D01 <- b
 
       if (verbose) {
         if (mode != "alternate") {
@@ -1662,7 +1663,7 @@ plot_GrowthCurve <- function(
             " | De = ",
             round(abs(De), digits = 2),
             " | D01 = ",
-            D01,
+            round(D01,2),
             " | c = ",
             round(c, digits = 2)
           ))
@@ -1718,9 +1719,7 @@ plot_GrowthCurve <- function(
           # calculate x.natural for error calculation
           if(mode == "interpolation"){
             x.natural[i]<-suppressWarnings(
-              round(
-                -(var.b[i] * (( (var.a[i] - data.MC.De[i])/var.a[i])^var.c[i] - 1) * ( ((var.a[i] - data.MC.De[i])/var.a[i])^-var.c[i]  )) / var.c[i],
-                digits=2))
+                -(var.b[i] * (( (var.a[i] - data.MC.De[i])/var.a[i])^var.c[i] - 1) * ( ((var.a[i] - data.MC.De[i])/var.a[i])^-var.c[i]  )) / var.c[i])
 
           }else if(mode == "extrapolation"){
             x.natural[i]<-suppressWarnings(
@@ -1752,7 +1751,7 @@ plot_GrowthCurve <- function(
   #Get De values from Monto Carlo simulation
 
   #calculate mean and sd (ignore NaN values)
-  De.MonteCarlo<-round(mean(na.exclude(x.natural)),digits=2)
+  De.MonteCarlo <- mean(na.exclude(x.natural))
 
   #De.Error is Error of the whole De (ignore NaN values)
   De.Error <- sd(na.exclude(x.natural))
@@ -1829,9 +1828,8 @@ plot_GrowthCurve <- function(
 
   }
 
-  ##============================================================================##
-  # PLOTTING ---------------------------------------------------------------------
-  ##============================================================================##
+
+# Plotting ------------------------------------------------------------------------------------
 
   ##5. Plotting if plotOutput==TRUE
   if(output.plot) {
@@ -1896,6 +1894,7 @@ plot_GrowthCurve <- function(
 
     }
 
+
     fun   <- if("fun" %in% names(extraArgs)) {extraArgs$fun} else {FALSE}
 
 
@@ -2184,9 +2183,9 @@ plot_GrowthCurve <- function(
                       substitute(D[e[MC]] == De,
                                  list(
                                    De = paste(
-                                     De.MonteCarlo,
+                                     round(De.MonteCarlo, 2),
                                      "\u00B1",
-                                     De.Error,
+                                     round(De.Error,2),
                                      " | quality = ",
                                      round((1 - abs(De - De.MonteCarlo) / De) * 100,
                                            digits =
@@ -2226,8 +2225,8 @@ plot_GrowthCurve <- function(
               1:length(sample[, "TnTx"]),
               sample[1:(length(sample[, "TnTx"])), "TnTx"] / sample[1, "TnTx"],
               xlab = "SAR cycle",
-              ylab = expression(paste(T[n] / T[x])),
-              main = "Test dose response",
+              ylab = expression(paste(T[x] / T[n])),
+              main = "Test-dose response",
               type = "o",
               pch = 20,
             )
