@@ -7,93 +7,100 @@
 #' by the extremes and outliers shown as points) and also the mean and
 #' standard deviation as pale bold line and pale polygon, respectively.
 #'
-#' The function allows passing several plot arguments, such as \code{main},
-#' \code{xlab}, \code{cex}. However, as the figure is an overlay of two
-#' separate plots, \code{ylim} must be specified in the order: c(ymin_axis1,
+#' The function allows passing several plot arguments, such as `main`,
+#' `xlab`, `cex`. However, as the figure is an overlay of two
+#' separate plots, `ylim` must be specified in the order: c(ymin_axis1,
 #' ymax_axis1, ymin_axis2, ymax_axis2) when using the cumulative values plot
 #' option. See examples for some further explanations. For details on the
-#' calculation of the bin-width (parameter \code{bw}) see
-#' \code{\link{density}}.\cr\cr
+#' calculation of the bin-width (parameter `bw`) see
+#' [density].
+#'
+#'
 #' A statistic summary, i.e. a collection of statistic measures of
 #' centrality and dispersion (and further measures) can be added by specifying
 #' one or more of the following keywords:
-#' \itemize{
-#' \item \code{"n"} (number of samples)
-#' \item \code{"mean"} (mean De value)
-#' \item \code{"median"} (median of the De values)
-#' \item \code{"sd.rel"} (relative standard deviation in percent)
-#' \item \code{"sd.abs"} (absolute standard deviation)
-#' \item \code{"se.rel"} (relative standard error)
-#' \item \code{"se.abs"} (absolute standard error)
-#' \item \code{"in.2s"} (percent of samples in 2-sigma range)
-#' \item \code{"kurtosis"} (kurtosis)
-#' \item \code{"skewness"} (skewness)
-#' }
-#' Note that the input data for the statistic summary is sent to the function
-#' \code{calc_Statistics()} depending on the log-option for the z-scale. If
-#' \code{"log.z = TRUE"}, the summary is based on the logarithms of the input
-#' data. If \code{"log.z = FALSE"} the linearly scaled data is used. \cr
-#' Note as well, that \code{"calc_Statistics()"} calculates these statistic
-#' measures in three different ways: \code{unweighted}, \code{weighted} and
-#' \code{MCM-based} (i.e., based on Monte Carlo Methods). By default, the
+#' - `"n"` (number of samples)
+#' - `"mean"` (mean De value)
+#' - `"median"` (median of the De values)
+#' - `"sd.rel"` (relative standard deviation in percent)
+#' - `"sd.abs"` (absolute standard deviation)
+#' - `"se.rel"` (relative standard error)
+#' - `"se.abs"` (absolute standard error)
+#' - `"in.2s"` (percent of samples in 2-sigma range)
+#' - `"kurtosis"` (kurtosis)
+#' - `"skewness"` (skewness)
+#'
+#'
+#' **Note** that the input data for the statistic summary is sent to the function
+#' `calc_Statistics()` depending on the log-option for the z-scale. If
+#' `"log.z = TRUE"`, the summary is based on the logarithms of the input
+#' data. If `"log.z = FALSE"` the linearly scaled data is used.
+#'
+#' **Note** as well, that `"calc_Statistics()"` calculates these statistic
+#' measures in three different ways: `unweighted`, `weighted` and
+#' `MCM-based` (i.e., based on Monte Carlo Methods). By default, the
 #' MCM-based version is used. If you wish to use another method, indicate this
-#' with the appropriate keyword using the argument \code{summary.method}.\cr\cr
-#' @param data \code{\link{data.frame}} or \code{\linkS4class{RLum.Results}}
-#' object (required): for \code{data.frame}: two columns: De
-#' (\code{values[,1]}) and De error (\code{values[,2]}). For plotting multiple
-#' data sets, these must be provided as \code{list} (e.g. \code{list(dataset1,
-#' dataset2)}).
+#' with the appropriate keyword using the argument `summary.method`.
 #'
-#' @param na.rm \code{\link{logical}} (with default): exclude NA values
-#' from the data set prior to any further operations.
 #'
-#' @param values.cumulative \code{\link{logical}} (with default): show
-#' cumulative individual data.
+#' @param data [data.frame] or [RLum.Results-class] object (**required**):
+#' for `data.frame`: two columns: De (`values[,1]`) and De error (`values[,2]`).
+#' For plotting multiple data sets, these must be provided as
+#' `list` (e.g. `list(dataset1, dataset2)`).
 #'
-#' @param order \code{\link{logical}}: Order data in ascending order.
+#' @param na.rm [logical] (*with default*):
+#' exclude NA values from the data set prior to any further operation.
 #'
-#' @param boxplot \code{\link{logical}} (with default): optionally show a
-#' boxplot (depicting median as thick central line, first and third quartile
-#' as box limits, whiskers denoting +/- 1.5 interquartile ranges and dots
-#' further outliers).
+#' @param values.cumulative [logical] (*with default*):
+#' show cumulative individual data.
 #'
-#' @param rug \code{\link{logical}} (with default): optionally add rug.
+#' @param order [logical]:
+#' Order data in ascending order.
 #'
-#' @param summary \code{\link{character}} (optional): add statistic measures of
-#' centrality and dispersion to the plot. Can be one or more of several
-#' keywords. See details for available keywords.
+#' @param boxplot [logical] (*with default*):
+#' optionally show a boxplot (depicting median as thick central line,
+#' first and third quartile as box limits, whiskers denoting +/- 1.5
+#' interquartile ranges and dots further outliers).
 #'
-#' @param summary.pos \code{\link{numeric}} or \code{\link{character}} (with
-#' default): optional position coordinates or keyword (e.g. \code{"topright"})
-#' for the statistical summary. Alternatively, the keyword \code{"sub"} may be
+#' @param rug [logical] (*with default*):
+#' optionally add rug.
+#'
+#' @param summary [character] (*optional*):
+#' add statistic measures of centrality and dispersion to the plot. Can be one
+#' or more of several keywords. See details for available keywords.
+#'
+#' @param summary.pos [numeric] or [character] (*with default*):
+#' optional position coordinates or keyword (e.g. `"topright"`)
+#' for the statistical summary. Alternatively, the keyword `"sub"` may be
 #' specified to place the summary below the plot header. However, this latter
-#' option in only possible if \code{mtext} is not used. In case of coordinate
+#' option in only possible if `mtext` is not used. In case of coordinate
 #' specification, y-coordinate refers to the right y-axis.
 #'
-#' @param summary.method \code{\link{character}} (with default): keyword
-#' indicating the method used to calculate the statistic summary. One out of
-#' \code{"unweighted"}, \code{"weighted"} and \code{"MCM"}. See
-#' \code{\link{calc_Statistics}} for details.
+#' @param summary.method [character] (*with default*):
+#' keyword indicating the method used to calculate the statistic summary.
+#' One out of `"unweighted"`, `"weighted"` and `"MCM"`.
+#' See [calc_Statistics] for details.
 #'
-#' @param bw \code{\link{character}} (with default): bin-width, chose a numeric
-#' value for manual setting.
+#' @param bw [character] (*with default*):
+#' bin-width, chose a numeric value for manual setting.
 #'
-#' @param output \code{\link{logical}}: Optional output of numerical plot
-#' parameters. These can be useful to reproduce similar plots. Default is
-#' \code{FALSE}.
+#' @param output [logical]:
+#' Optional output of numerical plot parameters. These can be useful to
+#' reproduce similar plots. Default is `TRUE`.
 #'
-#' @param \dots further arguments and graphical parameters passed to
-#' \code{\link{plot}}.
+#' @param ... further arguments and graphical parameters passed to [plot].
 #'
-#' @note The plot output is no 'probability density' plot (cf. the discussion
+#' @note
+#' The plot output is no 'probability density' plot (cf. the discussion
 #' of Berger and Galbraith in Ancient TL; see references)!
 #'
-#' @section Function version: 3.5.3
+#' @section Function version: 3.6.0
 #'
-#' @author Michael Dietze, GFZ Potsdam (Germany),\cr Sebastian Kreutzer,
-#' IRAMAT-CRP2A, Universite Bordeaux Montaigne
+#' @author
+#' Michael Dietze, GFZ Potsdam (Germany)\cr
+#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS-Université Bordeaux Montaigne, France
 #'
-#' @seealso \code{\link{density}}, \code{\link{plot}}
+#' @seealso [density], [plot]
 #'
 #' @examples
 #'
@@ -149,6 +156,7 @@
 #' KDE_out <- plot_KDE(data = ExampleData.DeValues,
 #' output = TRUE)
 #'
+#' @md
 #' @export
 plot_KDE <- function(
   data,
@@ -161,7 +169,7 @@ plot_KDE <- function(
   summary.pos,
   summary.method = "MCM",
   bw = "nrd0",
-  output = FALSE,
+  output = TRUE,
   ...
 ) {
 
@@ -169,61 +177,81 @@ plot_KDE <- function(
 
   ## account for depreciated arguments
   if("centrality" %in% names(list(...))) {
-
     boxplot <- TRUE
-
     warning(paste("[plot_KDE()] Argument 'centrality' no longer supported. ",
                   "Replaced by 'boxplot = TRUE'."))
   }
 
   if("dispersion" %in% names(list(...))) {
-
     boxplot <- TRUE
-
     warning(paste("[plot_KDE()] Argument 'dispersion' no longer supported. ",
                   "Replaced by 'boxplot = TRUE'."))
   }
 
   if("polygon.col" %in% names(list(...))) {
-
     boxplot <- TRUE
-
     warning(paste("[plot_KDE()] Argument 'polygon.col' no longer supported. ",
                   "Replaced by 'boxplot = TRUE'."))
   }
 
   if("weights" %in% names(list(...))) {
-
     warning(paste("[plot_KDE()] Argument 'weights' no longer supported. ",
                   "Weights are omitted."))
   }
 
   ## Homogenise input data format
   if(is(data, "list") == FALSE) {
-
     data <- list(data)
+
   }
 
   ## check/adjust input data structure
   for(i in 1:length(data)) {
-
     if(is(data[[i]], "RLum.Results") == FALSE &
          is(data[[i]], "data.frame") == FALSE &
          is.numeric(data[[i]]) == FALSE) {
       stop(paste("[plot_KDE()] Input data format is neither",
-                 "'data.frame', 'RLum.Results' nor 'numeric'"))
+                 "'data.frame', 'RLum.Results' nor 'numeric'"), call. = FALSE)
     } else {
 
+      ##extract RLum.Results
       if(is(data[[i]], "RLum.Results") == TRUE) {
         data[[i]] <- get_RLum(data[[i]], "data")[,1:2]
       }
 
+      ##make sure we only take the first two columns
+      data[[i]] <- data[[i]][,1:2]
+
+
+      ##account for very short datasets
       if(length(data[[i]]) < 2) {
         data[[i]] <- cbind(data[[i]], rep(NA, length(data[[i]])))
       }
+
     }
+
+    ##check for Inf values and remove them if need
+    if(any(is.infinite(unlist(data[[i]])))){
+      Inf_id <- which(is.infinite(unlist(data[[i]]))[1:nrow(data[[i]])/ncol(data[[i]])])
+      warning(paste("[plot_KDE()] Inf values removed in row(s):", paste(Inf_id, collapse = ", "), "in data.frame", i), call. = FALSE)
+      data[[i]] <- data[[i]][-Inf_id,]
+      rm(Inf_id)
+
+      ##check if empty
+      if(nrow(data[[i]]) == 0){
+        data[i] <- NULL
+
+      }
+
+    }
+
   }
 
+  ##check if list is empty
+  if(length(data) == 0)
+    stop("[plot_KDE()] Your input is empty, intentionally or maybe after Inf removal? Nothing plotted!", call. = FALSE)
+
+
   ## check/set function parameters
   if(missing(summary) == TRUE) {
     summary <- ""
@@ -287,7 +315,7 @@ plot_KDE <- function(
 
   ## loop through all data sets
   for(i in 1:length(data)) {
-    statistics <- calc_Statistics(data[[i]])[[summary.method]]
+    statistics <- calc_Statistics(data[[i]], na.rm = na.rm)[[summary.method]]
 
     De.stats[i,1] <- statistics$n
     De.stats[i,2] <- statistics$mean
@@ -329,7 +357,7 @@ plot_KDE <- function(
     De.error.global <- c(De.error.global, data[[i]][,2])
 
     ## density range
-    if(!is.na(De.density[[i]])){
+    if(!all(is.na(De.density[[i]]))){
       De.density.range[i,1] <- min(De.density[[i]]$x)
       De.density.range[i,2] <- max(De.density[[i]]$x)
       De.density.range[i,3] <- min(De.density[[i]]$y)
@@ -628,6 +656,8 @@ plot_KDE <- function(
     col.value.bar <- list(...)$col
     col.value.rug <- list(...)$col
     col.boxplot <- list(...)$col
+    col.boxplot.line <- list(...)$col
+    col.boxplot.fill <- NA
     col.mean.line <- adjustcolor(col = list(...)$col,
                                  alpha.f = 0.4)
     col.sd.bar <- adjustcolor(col = list(...)$col,
@@ -636,99 +666,105 @@ plot_KDE <- function(
   } else {
 
     if(length(layout$kde$colour$main) == 1) {
-      col.main <- 1:length(data)
+      col.main <- c(layout$kde$colour$main, 2:length(data))
     } else {
       col.main <- layout$kde$colour$main
     }
 
     if(length(layout$kde$colour$xlab) == 1) {
-      col.xlab <- 1:length(data)
+      col.xlab <- c(layout$kde$colour$xlab, 2:length(data))
     } else {
       col.xlab <- layout$kde$colour$xlab
     }
 
     if(length(layout$kde$colour$ylab1) == 1) {
-      col.ylab1 <- 1:length(data)
+      col.ylab1 <- c(layout$kde$colour$ylab1, 2:length(data))
     } else {
       col.ylab1 <- layout$kde$colour$ylab1
     }
 
     if(length(layout$kde$colour$ylab2) == 1) {
-      col.ylab2 <- 1:length(data)
+      col.ylab2 <- c(layout$kde$colour$ylab2, 2:length(data))
     } else {
       col.ylab2 <- layout$kde$colour$ylab2
     }
 
     if(length(layout$kde$colour$xtck) == 1) {
-      col.xtck <- 1:length(data)
+      col.xtck <- c(layout$kde$colour$xtck, 2:length(data))
     } else {
       col.xtck <- layout$kde$colour$xtck
     }
 
     if(length(layout$kde$colour$ytck1) == 1) {
-      col.ytck1 <- 1:length(data)
+      col.ytck1 <- c(layout$kde$colour$ytck1, 2:length(data))
     } else {
       col.ytck1 <- layout$kde$colour$ytck1
     }
 
     if(length(layout$kde$colour$ytck2) == 1) {
-      col.ytck2 <- 1:length(data)
+      col.ytck2 <- c(layout$kde$colour$ytck2, 2:length(data))
     } else {
       col.ytck2 <- layout$kde$colour$ytck2
     }
 
     if(length(layout$kde$colour$box) == 1) {
-      col.box <- 1:length(data)
+      col.box <- c(layout$kde$colour$box, 2:length(data))
     } else {
       col.box <- layout$kde$colour$box
     }
 
     if(length(layout$kde$colour$mtext) == 1) {
-      col.mtext <- 1:length(data)
+      col.mtext <- c(layout$kde$colour$mtext, 2:length(data))
     } else {
       col.mtext <- layout$kde$colour$mtext
     }
 
     if(length(layout$kde$colour$stats) == 1) {
-      col.stats <- 1:length(data)
+      col.stats <- c(layout$kde$colour$stats, 2:length(data))
     } else {
       col.stats <- layout$kde$colour$stats
     }
 
     if(length(layout$kde$colour$kde.line) == 1) {
-      col.kde.line <- 1:length(data)
+      col.kde.line <- c(layout$kde$colour$kde.line, 2:length(data))
     } else {
       col.kde.line <- layout$kde$colour$kde.line
     }
 
     if(length(layout$kde$colour$kde.fill) == 1) {
-      col.kde.fill <- 1:length(data)
+      col.kde.fill <- c(layout$kde$colour$kde.fill, 2:length(data))
     } else {
       col.kde.fill <- layout$kde$colour$kde.fill
     }
 
     if(length(layout$kde$colour$value.dot) == 1) {
-      col.value.dot <- 1:length(data)
+      col.value.dot <- c(layout$kde$colour$value.dot, 2:length(data))
     } else {
       col.value.dot <- layout$kde$colour$value.dot
     }
 
     if(length(layout$kde$colour$value.bar) == 1) {
-      col.value.bar <- 1:length(data)
+      col.value.bar <- c(layout$kde$colour$value.bar, 2:length(data))
     } else {
       col.value.bar <- layout$kde$colour$value.bar
     }
 
     if(length(layout$kde$colour$value.rug) == 1) {
-      col.value.rug <- 1:length(data)
+      col.value.rug <- c(layout$kde$colour$value.rug, 2:length(data))
     } else {
       col.value.rug <- layout$kde$colour$value.rug
     }
 
-    if(length(layout$kde$colour$boxplot) == 1) {
-      col.boxplot <- 1:length(data)
+    if(length(layout$kde$colour$boxplot.line) == 1) {
+      col.boxplot.line <- c(layout$kde$colour$boxplot.line, 2:length(data))
     } else {
-      col.boxplot <- layout$kde$colour$boxplot
+      col.boxplot.line <- layout$kde$colour$boxplot.line
+    }
+
+    if(length(layout$kde$colour$boxplot.fill) == 1) {
+      col.boxplot.fill <- c(layout$kde$colour$boxplot.fill, 2:length(data))
+    } else {
+      col.boxplot.fill <- layout$kde$colour$boxplot.fill
     }
 
     if(length(layout$kde$colour$mean.line) == 1) {
@@ -739,13 +775,13 @@ plot_KDE <- function(
     }
 
     if(length(layout$kde$colour$sd.bar) == 1) {
-      col.sd.bar <- 1:length(data)
+      col.sd.bar <- c(layout$kde$colour$sd.bar, 2:length(data))
     } else {
       col.sd.bar <- layout$kde$colour$sd.line
     }
 
     if(length(layout$kde$colour$background) == 1) {
-      col.background <- 1:length(data)
+      col.background <- c(layout$kde$colour$background, 2:length(data))
     } else {
       col.background <- layout$kde$colour$background
     }
@@ -931,11 +967,11 @@ plot_KDE <- function(
         cex = cex * layout$kde$font.size$ylab1/12)
 
   for(i in 1:length(data)) {
-    if(!is.na(De.density[[i]])){
+    if(!all(is.na(De.density[[i]]))){
       polygon(x = c(par()$usr[1], De.density[[i]]$x, par()$usr[2]),
               y = c(min(De.density[[i]]$y),De.density[[i]]$y, min(De.density[[i]]$y)),
               border = col.kde.line[i],
-              col = col.kde.fill,
+              col = col.kde.fill[i],
               lty = lty[i],
               lwd = lwd[i])
 
@@ -1071,7 +1107,7 @@ plot_KDE <- function(
               y = c(-11/8 * l_height,
                     -7/8 * l_height),
               lwd = 2,
-              col = col.boxplot[i])
+              col = col.boxplot.line[i])
 
         ## draw q25-q75-polygon
         polygon(x = c(boxplot.data[[i]]$stats[2,1],
@@ -1082,38 +1118,39 @@ plot_KDE <- function(
                       -7/8 * l_height,
                       -7/8 * l_height,
                       -11/8 * l_height),
-                border = col.boxplot[i])
+                col = col.boxplot.fill[i],
+                border = col.boxplot.line[i])
 
         ## draw whiskers
         lines(x = c(boxplot.data[[i]]$stats[2,1],
                     boxplot.data[[i]]$stats[1,1]),
               y = c(-9/8 * l_height,
                     -9/8 * l_height),
-              col = col.boxplot[i])
+              col = col.boxplot.line[i])
 
         lines(x = c(boxplot.data[[i]]$stats[1,1],
                     boxplot.data[[i]]$stats[1,1]),
               y = c(-10/8 * l_height,
                     -8/8 * l_height),
-              col = col.boxplot[i])
+              col = col.boxplot.line[i])
 
         lines(x = c(boxplot.data[[i]]$stats[4,1],
                     boxplot.data[[i]]$stats[5,1]),
               y = c(-9/8 * l_height,
                     -9/8 * l_height),
-              col = col.boxplot[i])
+              col = col.boxplot.line[i])
 
         lines(x = c(boxplot.data[[i]]$stats[5,1],
                     boxplot.data[[i]]$stats[5,1]),
               y = c(-10/8 * l_height,
                     -8/8 * l_height),
-              col = col.boxplot[i])
+              col = col.boxplot.line[i])
 
         ## draw outliers
         points(x = boxplot.data[[i]]$out,
                y = rep(-9/8 * l_height,
                        length(boxplot.data[[i]]$out)),
-               col = col.boxplot[i],
+               col = col.boxplot.line[i],
                cex = cex * 0.8)
       }
 
@@ -1172,9 +1209,9 @@ plot_KDE <- function(
 
     ## add De error bars
     for(i in 1:length(data)) {
-      arrows(data[[i]][,1] - data[[i]][,2]/2,
+      arrows(data[[i]][,1] - data[[i]][,2],
              1:length(data[[i]][,1]),
-             data[[i]][,1] + data[[i]][,2]/2,
+             data[[i]][,1] + data[[i]][,2],
              1:length(data[[i]][,1]),
              code = 3,
              angle = 90,
@@ -1205,9 +1242,10 @@ plot_KDE <- function(
   if(fun==TRUE){sTeve()}
 
   if(output == TRUE) {
-    return(list(De.stats = De.stats,
-                summary.pos = summary.pos,
-                De.density = De.density))
+    return(invisible(list(De.stats = De.stats,
+                          summary.pos = summary.pos,
+                          De.density = De.density)))
   }
 
 }
+
